var expect = require('chai').expect;

var express = require('./express');

var request = require('superagent');

describe('express', () => {

    var sut;
    afterEach(() => {
        if (sut) {
            sut.stop();
        }
    });

    describe('with simple cmd=test', () => {

        beforeEach((done) => {
            sut = express('test', {
                port: 9100,
                handler: (msg, reply) => {
                    reply({response: 'test'});
                }
            });

            sut.listen()
                .then(() => {
                    done();
                });
        });

        it('cmd=test returns response with test', (done) => {

            request.get('http://localhost:9100/api')
                .end((err, resp) => {
                    if (resp.body.response === 'test') {
                        done();
                    }
                    else {
                        done(new Error('error'));
                    }
                });
        });
    });

    describe('with cmd=test with echo value', () => {

        beforeEach((done) => {
            sut = express('test', {
                port: 9100,
                handler: (msg, reply) => {
                    reply(msg);
                }
            });

            sut.listen()
                .then(() => {
                    done();
                });
        });

        it('get with cmd=test&value=testvalue returns response with testvalue', (done) => {

            request.get('http://localhost:9100/api?cmd=test&value=testvalue')
                .end((err, resp) => {
                    if (resp.body.cmd === 'test' && resp.body.value === 'testvalue') {
                        done();
                    }
                    else {
                        done(new Error('error'));
                    }
                });
        });

        it('post with cmd=test and body value=testvalue returns response with testvalue', (done) => {

            request.post('http://localhost:9100/api?cmd=test')
                .send({value: 'testvalue'})
                .end((err, resp) => {
                    console.log('body: ', resp.body);
                    if (resp.body.cmd === 'test' && resp.body.value === 'testvalue') {
                        done();
                    }
                    else {
                        done(new Error('error'));
                    }
                });
        });
    });
});